@@ -32,7 +32,7 @@ EXIT_FAILURE=1
 
 # Where the tool is installed.
 # default is relative path to installed location of the tools
-prefix="${prefix:-../../../}"
+prefix="${prefix:-../../..}"
 AR="ar"
 RANLIB="ranlib"
 H5TOOL="h5c++"                  # The tool name
